@@ -9,6 +9,7 @@ from rich.console import Console
 from rich.table import Column, Table
 from .properties import files
 from .setup import setup
+from .tutorial import tutorial
 
 chdir(dirname(__file__))
 default = {'history': '', 'instances': '[]', 'key': '', 'account': '{}'}
@@ -23,7 +24,7 @@ with open(files['key'], 'r') as f:
 
 
 def cli():
-    pass
+    ...
 
 
 def set_api_key():
@@ -247,9 +248,10 @@ while 1:
                 print('Usage: del <name>')
             else:
                 delete_instance(cmd[1])
+        elif cmd[0] == 'tutorial':
+            tutorial()
         elif cmd[0] == 'help':
-            print('''\
-Usage:
+            print('''Usage:
     key                               Set API key.
     user <username>                   Set username for VPN connection.
     pwd                               Set password for VPN connection.
@@ -260,6 +262,8 @@ Usage:
     ls                                List all instances.
     info <name>                       Get information about an instance.
     del <name>                        Delete an instance.
+    exit                              Exit Span.
+    tutorial                          Enter interactive tutorial.
     help                              Show this message.''')
         elif cmd[0] == 'exit':
             break
